@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,7 +20,7 @@
 #include "grantleeeditor-version.h"
 #include "themeeditormainwindow.h"
 #include <QApplication>
-#include <kaboutdata.h>
+#include <KAboutData>
 #include <KDBusService>
 #include <KLocalizedString>
 #include <QCommandLineParser>
@@ -38,7 +38,7 @@ int main(int argc, char **argv)
                          QStringLiteral(GRANTLEEEDITOR_VERSION),
                          i18n("Contact Print Theme Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2015-2019 contactprintthemeeditor authors"));
+                         i18n("Copyright © 2015-2020 contactprintthemeeditor authors"));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kaddressbook")));
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
